@@ -1,5 +1,5 @@
 package User::SessionRestoring;
-use base qw/Catalyst::Authentication::User::Hash/;
+use base qw/Catalyst::Plugin::Authentication::User::Hash/;
 
 sub for_session { $_[0]->id }
 sub store { $_[0]->{store} }
@@ -39,36 +39,18 @@ sub elk : Local {
 	ok( $c->user_exists, "user exists" );
 	ok( $c->user, "a user was also restored");
 	is_deeply( $c->user, $users->{foo}, "restored user is the right one (deep test - store might change identity)" );
-    
-    $c->logout;
+
+	$c->delete_session("bah");
 }
 
 sub fluffy_bunny : Local {
 	my ( $self, $c ) = @_;
 
-	ok( $c->session_is_valid, "no session ID was restored");
-	ok( !$c->user, "no user was restored");
-	
-    $c->delete_session("bah");
-}
-
-sub possum : Local {
-    my ( $self, $c ) = @_;
-
 	ok( !$c->session_is_valid, "no session ID was restored");
-    $c->session->{definitely_not_a_user} = "moose";
-
+	ok( !$c->user, "no user was restored");
 }
 
-sub butterfly : Local {
-    my ( $self, $c ) = @_;
-
-    ok( $c->session_is_valid, "valid session" );
-    ok( !$c->user_exists, "but no user exists" );
-    ok( !$c->user, "no user object either" );
-}
-
-__PACKAGE__->config->{'Plugin::Authentication'}{users} = $users = {
+__PACKAGE__->config->{authentication}{users} = $users = {
 	foo => User::SessionRestoring->new(
 		id => 'foo',
 		password => "s3cr3t",
